@@ -1,19 +1,22 @@
-
-context("currencies")
-
 test_that("it should get currency data from BCB", {
-  skip_on_cran()
+  if (!covr::in_covr()) {
+    skip_on_cran()
+    skip_if_offline()
+  }
 
   x <- get_currency("USD", "2017-03-01", "2017-03-02", as = "text")
-  expect_is(x, "character")
+  expect_type(x, "character")
   expect_equal(x, "01032017;220;A;USD;3,0970;3,0976;1,0000;1,0000\n02032017;220;A;USD;3,1132;3,1138;1,0000;1,0000\n")
 })
 
 test_that("it should get a time series of a currency from bcb", {
-  skip_on_cran()
+  if (!covr::in_covr()) {
+    skip_on_cran()
+    skip_if_offline()
+  }
 
   x <- get_currency("USD", "2017-03-01", "2017-03-14")
-  expect_is(x, "data.frame")
+  expect_s3_class(x, "data.frame")
   expect_equal(dim(x), c(10, 3))
   expect_error(
     get_currency("BRL", "2017-03-01", "2017-03-14")
@@ -21,36 +24,48 @@ test_that("it should get a time series of a currency from bcb", {
 })
 
 test_that("it should get currency code", {
-  skip_on_cran()
+  if (!covr::in_covr()) {
+    skip_on_cran()
+    skip_if_offline()
+  }
 
   x <- get_currency_id("BRL")
   expect_equal(x, 177)
 })
 
 test_that("it should get MXN and ARS data", {
-  skip_on_cran()
+  if (!covr::in_covr()) {
+    skip_on_cran()
+    skip_if_offline()
+  }
 
   x <- get_currency("MXN", "2018-05-28", "2018-05-30")
-  expect_is(x, "data.frame")
+  expect_s3_class(x, "data.frame")
   expect_equal(dim(x), c(3, 3))
   x <- get_currency("ARS", "2018-05-28", "2018-05-30")
-  expect_is(x, "data.frame")
+  expect_s3_class(x, "data.frame")
   expect_equal(dim(x), c(3, 3))
 })
 
 test_that("it should get a time series with a symbol attribute", {
-  skip_on_cran()
+  if (!covr::in_covr()) {
+    skip_on_cran()
+    skip_if_offline()
+  }
 
   x <- get_currency("USD", "2017-03-01", "2017-03-14")
-  expect_is(x, "data.frame")
+  expect_s3_class(x, "data.frame")
   expect_equal(attr(x, "symbol"), "USD")
   x <- get_currency("USD", "2017-03-01", "2017-03-14", as = "xts")
-  expect_is(x, "xts")
+  expect_s3_class(x, "xts")
   expect_equal(attr(x, "symbol"), "USD")
 })
 
 test_that("it should get ask/bid time series named with symbol", {
-  skip_on_cran()
+  if (!covr::in_covr()) {
+    skip_on_cran()
+    skip_if_offline()
+  }
 
   x <- get_currency("USD", "2017-03-01", "2017-03-14")
   x_ask <- Ask(x)
@@ -64,3 +79,23 @@ test_that("it should get ask/bid time series named with symbol", {
   expect_equal(colnames(x_bid), "USD")
 })
 
+test_that("it should get cross currency rates", {
+  if (!covr::in_covr()) {
+    skip_on_cran()
+    skip_if_offline()
+  }
+
+  x <- get_currency_cross_rates("2017-03-10")
+  d <- dim(x)
+  expect_equal(d[1], d[2])
+})
+
+test_that("it should list currencies", {
+  if (!covr::in_covr()) {
+    skip_on_cran()
+    skip_if_offline()
+  }
+
+  x <- list_currencies()
+  expect_s3_class(x, "data.frame")
+})
